@@ -1,22 +1,8 @@
 /*
-Copyright 2008-2014 Nick Shaforostoff <shaforostoff@kde.ru>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2008-2014 Nick Shaforostoff <shaforostoff@kde.ru>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License or (at your option) version 3 or any later version
-accepted by the membership of KDE e.V. (or its successor approved
-by the membership of KDE e.V.), which shall act as a proxy
-defined in Section 14 of version 3 of the license.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "gettextstorage.h"
@@ -332,9 +318,9 @@ QVector<Note> GettextStorage::notes(const DocPosition& docPosition, const QRegEx
     QVector<Note> result;
     QString content;
 
-    QStringList note = m_entries.at(docPosition.entry).comment().split('\n').filter(re);
+    const QStringList note = m_entries.at(docPosition.entry).comment().split('\n').filter(re);
 
-    foreach (const QString &s, note) {
+    for (const QString &s : note) {
         if (s.size() >= preLen) {
             content += s.midRef(preLen);
             content += QLatin1Char('\n');
@@ -369,16 +355,20 @@ QStringList GettextStorage::sourceFiles(const DocPosition& pos) const
     QStringList commentLines = m_entries.at(pos.entry).comment().split('\n');
 
     static const QRegExp i18n_file_re(QStringLiteral("^#. i18n: file: "));
-    foreach (const QString &uiLine, commentLines.filter(i18n_file_re)) {
-        foreach (const QStringRef &fileRef, uiLine.midRef(15).split(' ')) {
+    const auto uiLines = commentLines.filter(i18n_file_re);
+    for (const QString &uiLine : uiLines) {
+        const auto fileRefs = uiLine.midRef(15).split(' ');
+        for (const QStringRef &fileRef : fileRefs) {
             result << fileRef.toString();
         }
     }
 
     bool hasUi = !result.isEmpty();
     static const QRegExp cpp_re(QStringLiteral("^#: "));
-    foreach (const QString &cppLine, commentLines.filter(cpp_re)) {
-        foreach (const QStringRef &fileRef, cppLine.midRef(3).split(' ')) {
+    const auto cppLines = commentLines.filter(cpp_re);
+    for (const QString &cppLine : cppLines) {
+        const auto fileRefs = cppLine.midRef(3).split(' ');
+        for (const QStringRef &fileRef : fileRefs) {
             if (hasUi && fileRef.startsWith(QLatin1String("rc.cpp:"))) {
                 continue;
             }
@@ -476,7 +466,7 @@ bool GettextStorage::setHeader(const CatalogItem& newHeader)
         m_header.setMsgstr(values);
 
 //       setClean(false);
-        //emit signalHeaderChanged();
+        //Q_EMIT signalHeaderChanged();
 
         return true;
     }
