@@ -1,22 +1,8 @@
 /*
-Copyright 2008-2014 Nick Shaforostoff <shaforostoff@kde.ru>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2008-2014 Nick Shaforostoff <shaforostoff@kde.ru>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License or (at your option) version 3 or any later version
-accepted by the membership of KDE e.V. (or its successor approved
-by the membership of KDE e.V.), which shall act as a proxy
-defined in Section 14 of version 3 of the license.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "tsstorage.h"
@@ -281,7 +267,7 @@ static QString doContent(QDomElement elem, int startingPos, TsContentEditingData
  * - deletes content, or
  * - inserts content
  */
-static QString content(QDomElement elem, TsContentEditingData* data = 0)
+static QString content(QDomElement elem, TsContentEditingData* data = nullptr)
 {
     return doContent(elem, 0, data);
 }
